Account
=======

You can edit your account in the Account tab.  You can change your real name,
e-mail and password.  You can also set the preferences.

.. warning::

   The real name is not changed on the posts already created.

.. note::

   If you want to change your username, you must contact an administrator.

.. admonition:: Permissions

   In order to enable the “Show me posts by other users by default” preference, you must
   first have the “can edit others’ posts” permission.
